@@ -1,7 +1,10 @@
 package
   Neo4j::Bolt::CResultStream;
+use v5.12;
+use warnings;
+
 BEGIN {
-  our $VERSION = "0.5000";
+  our $VERSION = "0.5002";
   require XSLoader;
   XSLoader::load();
 }
