@@ -1,9 +1,9 @@
 package Neo4j::Bolt::Path;
 # ABSTRACT: Representation of Neo4j Path
 
-$Neo4j::Bolt::Path::VERSION = '0.5000';
+$Neo4j::Bolt::Path::VERSION = '0.5002';
 
-use strict;
+use v5.12;
 use warnings;
 
 use parent 'Neo4j::Types::Path';
@@ -109,7 +109,7 @@ L<Neo4j::Bolt>, L<Neo4j::Types::Path>
 
 =head1 LICENSE
 
-This software is Copyright (c) 2020-2024 by Arne Johannessen.
+This software is Copyright (c) 2020-2026 by Arne Johannessen.
 
 This is free software, licensed under:
 
